==> babel-plugin-transform-lazy-0.0.1.tgz: package/README.md <==
[![Build Status](https://travis-ci.org/kaelzhang/babel-plugin-transform-lazy.svg?branch=master)](https://travis-ci.org/kaelzhang/babel-plugin-transform-lazy)
[![Coverage](https://codecov.io/gh/kaelzhang/babel-plugin-transform-lazy/branch/master/graph/badge.svg)](https://codecov.io/gh/kaelzhang/babel-plugin-transform-lazy)
<!-- optional appveyor tst
[![Windows Build Status](https://ci.appveyor.com/api/projects/status/github/kaelzhang/babel-plugin-transform-lazy?branch=master&svg=true)](https://ci.appveyor.com/project/kaelzhang/babel-plugin-transform-lazy)
-->
<!-- optional npm version
[![NPM version](https://badge.fury.io/js/babel-plugin-transform-lazy.svg)](http://badge.fury.io/js/babel-plugin-transform-lazy)
-->
<!-- optional npm downloads
[![npm module downloads per month](http://img.shields.io/npm/dm/babel-plugin-transform-lazy.svg)](https://www.npmjs.org/package/babel-plugin-transform-lazy)
-->
<!-- optional dependency status
[![Dependency Status](https://david-dm.org/kaelzhang/babel-plugin-transform-lazy.svg)](https://david-dm.org/kaelzhang/babel-plugin-transform-lazy)
-->

# babel-plugin-transform-lazy

(WORKING IN PROGRESS, DO NOT USE) Allow swift-like `lazy` keyword before class properties.

## Install

```sh
$ npm i babel-plugin-transform-lazy
```

## Usage

```js
class Foo {
  lazy x = () => createX(this.bar)

  constructor (bar) {
    this.bar = bar
  }
}
```

Out:

```js
const X = Symbol('private:x')

class Foo {
  constructor (bar) {
    this.bar = bar
  }

  get x () {
    if (X in this) {
      return this[X]
    }

    const x = (() => createX(this.bar))()
    this[X] = x
    return x
  }

  set x (value) {
    this[X] = value
  }
}
```

## License

MIT

==> babel-plugin-transform-lazy-0.0.2.tgz: package/README.md <==
[![Build Status](https://travis-ci.org/kaelzhang/babel-plugin-transform-lazy.svg?branch=master)](https://travis-ci.org/kaelzhang/babel-plugin-transform-lazy)
[![Coverage](https://codecov.io/gh/kaelzhang/babel-plugin-transform-lazy/branch/master/graph/badge.svg)](https://codecov.io/gh/kaelzhang/babel-plugin-transform-lazy)
<!-- optional appveyor tst
[![Windows Build Status](https://ci.appveyor.com/api/projects/status/github/kaelzhang/babel-plugin-transform-lazy?branch=master&svg=true)](https://ci.appveyor.com/project/kaelzhang/babel-plugin-transform-lazy)
-->
<!-- optional npm version
[![NPM version](https://badge.fury.io/js/babel-plugin-transform-lazy.svg)](http://badge.fury.io/js/babel-plugin-transform-lazy)
-->
<!-- optional npm downloads
[![npm module downloads per month](http://img.shields.io/npm/dm/babel-plugin-transform-lazy.svg)](https://www.npmjs.org/package/babel-plugin-transform-lazy)
-->
<!-- optional dependency status
[![Dependency Status](https://david-dm.org/kaelzhang/babel-plugin-transform-lazy.svg)](https://david-dm.org/kaelzhang/babel-plugin-transform-lazy)
-->

# babel-plugin-transform-lazy

(WORKING IN PROGRESS, DO NOT USE) Allow swift-like `lazy` keyword before class properties.

## Install

```sh
$ npm i babel-plugin-transform-lazy
```

## Usage

```js
class Foo {
  lazy x = createX(this.bar)

  constructor (bar) {
    this.bar = bar
  }
}
```

Out:

```js
const X = Symbol('private:x')

class Foo {
  constructor (bar) {
    this.bar = bar
  }

  get x () {
    if (X in this) {
      return this[X]
    }

    const x = (() => createX(this.bar))()
    this[X] = x
    return x
  }

  set x (value) {
    this[X] = value
  }
}
```

## License

MIT
